@@ -75,4 +75,10 @@ def test_version():
     fn = join(here, 'cheese_shop.py')
     with pytest.raises(SystemExit):
         args = cli().parse_args([fn, '--version'])
-        assert args.version == 'tranquilizer {}'.format(__version__)
\ No newline at end of file
+        assert args.version == 'tranquilizer {}'.format(__version__)
+
+def test_secret_key():
+    here = dirname(__file__)
+    fn = join(here, 'protected.py')
+    args = cli().parse_args([fn, '--secret-key', 'tranquilizer'])
+    assert args.secret_key == 'tranquilizer'
